@@ -44,4 +44,9 @@ def get_info(info_url):
         except:
             time.sleep(0.2)
             continue
-    raise ValueError('failed to get info')
\ No newline at end of file
+    raise ValueError('failed to get info')
+
+def is_token_tag(token_symbol_or_tag):
+    if token_symbol_or_tag.find('-') != -1:
+        return True
+    return False
\ No newline at end of file
